@@ -1,5 +1,5 @@
 #coding = utf-8
-__version__ = '0.3.12'
+__version__ = '0.4.0'
 
 import random
 from termcolor import colored, cprint
@@ -8,21 +8,29 @@ import time
 from art import *
 import os
 import json
-import requests
 import getpass
 import uuid
+from Morpion.datas import variables, loading, setGrid, getPlayers, notDone, isWinner 
+
+
+
 pathToScript = os.path.dirname(os.path.abspath(__file__))
+
+
 def pathToSave()->str:
     if platform.system() == 'Windows':
-        path = str(r"c:\Users\{}\PetchouApps".format(getpass.getuser()))
+        usr = str(getpass.getuser())
+        usr = usr[:5]
+        path = str(r"c:/Users/{}/PCCorp".format(usr))
         return path
     else:
-        return f"/Users/{getpass.getuser()}/PetchouApps"
+        return f"/Users/{getpass.getuser()}/PCCorp"
+
+print(__name__)
 
 
 
 
-from Morpion.datas import variables, loading, setGrid, getPlayers, notDone, isWinner, setIcon
 vars = variables()
 colors = vars.colors
 cases = vars.scheme
@@ -32,32 +40,23 @@ commands = {"Windows": ["cls", "exit"], "Linux":["clear", """
         """], "Darwin": ["clear", """
         osascript -e 'tell application "Terminal" to close first window' && exit
         """] }
+
 sys = platform.system()
 
-global grid1
-global grid2
-global grid3
-global grid4
-global grid5
+
 
 global joueurs
 joueurs = []
-'''
-bleu     0
-vert     1
-rouge    2
-jaune    3 
-cyan     4
-gris     5
-'''
 
 
+print(__name__)
+
 global Player1
 Player1 = colored("X", colors[2])
 global Player2
 Player2 = colored("O", colors[0])
 
-
+print(__name__)
 
 global coup
 coup = 0
@@ -80,7 +79,7 @@ def getCoup(p, casesDispo) -> int:
     return coup 
     
     
-
+print(__name__)
 
 def setGame(joueurs, gameManager):
 
@@ -143,7 +142,7 @@ def game(joueurs, gameManager):
         turn = 11
     EndScreen(turn, gameManager, p1, p2, p)
 
-    
+print(__name__)
 
 
 def eraseDatas(turn, gameManager, p1, p2, p):
@@ -220,9 +219,8 @@ def EndScreen(turn, gameManager, p1, p2, p):
         tprint('Settings')
         print("\nQue voulez-vous faire ?")
         print("1) Effacer les sauvegardes")
-        print("2) Créer l'icone de bureau")
-        print("3) Changer de Langue - pas encore disponible") 
-        print("4) Retour") 
+        print("2) Changer de Langue - pas encore disponible") 
+        print("3) Retour") 
 
         def endGameChoice() -> str:
             choice = input("")
@@ -234,9 +232,26 @@ def EndScreen(turn, gameManager, p1, p2, p):
         if mode == 1:
             eraseDatas(turn, gameManager, p1, p2, p)
         if mode == 2:
-            setIcon(sys, pathToScript)
+            pass
 
+def isFirst():
+    try:
+        with open(pathToSave()+"/save.json", "r"):
+            pass
+    except FileNotFoundError:
+        tprint('First use, initializing filesystem...')
+        os.mkdir(pathToSave())
+        save = open(pathToSave()+'save.json', "w")
+        debugDatas = {"#509 troubleshooting": "debug"}
+        json.dump(debugDatas, save)
+        save.close()
+
+
+
+print(__name__)
 if __name__ == "__main__":
+
+    isFirst()
     os.chdir(pathToScript)
     loading(__version__, pathToScript, pathToSave())
     os.system(commands[sys][0])
