@@ -4,42 +4,19 @@ import os
 import time
 import json
 import platform
-import requests
-import urllib3
 import getpass
-import pkg_resources
-def internet_on() ->bool:
-    url = "http://www.google.com"
-    timeout = 5
-    try:
-        request = requests.get(url, timeout=timeout)
-        return True
-    except (requests.ConnectionError, requests.Timeout) as exception:
-        return False
-
-def isfirst(pathToSave)->bool:
-    try:
-        with open(pathToSave+"/save.json", "r"):
-            pass
-    except FileNotFoundError:
-        print('Initializing filesystem')
-        print(pathToSave)
-        a = input('...')
-        os.system(f'mkdir {pathToSave}')
-        os.system(f'/Users/{getpass.getuser()}/PetchouApps/save.json')
-        with open(f"/Users/{getpass.getuser()}/PetchouApps/save.json", "w") as troubleshot:
-            dict_init = {"#509 troubleshooting": "debug"}
-            json.dump(dict_init, troubleshot)
-            a = input()
-        
 
 
-commands = {"Windows": ["cls", "exit", "pip install --upgrade Morpion ", "python -m Morpion"], "Linux":["clear", """
+
+
+commands = {"Windows": ["cls", quit(), "pip install --upgrade Morpion ", "python -m Morpion"], "Linux":["clear", """
         osascript -e 'tell application "Terminal" to close first window' && exit
         """, "pip3 install --upgrade Morpion", "python3 -m Morpion"], "Darwin": ["clear", """
         osascript -e 'tell application "Terminal" to close first window' && exit
         """, "pip3 install --upgrade Morpion ", "python3 -m Morpion"] }
+
 sys = platform.system()
+
 class variables():
     def __init__(self):
         self.colors = ['blue', 'green', 'red', 'yellow','cyan', 'grey']
@@ -53,20 +30,12 @@ def loadFormat(x, base=2) -> int:
 
 def loading(currentVersion, path, SavePath):
     
-    if isfirst(SavePath):
-        print('Bienvenue, ceci est votre première session, voulez-vous créer une icon de bureau ? En cas de refus, cette action sera toujours disponible dans les paramètres de fin de partie.')
-        print('non -> tapez n')
-        print("oui -> tapez n'importe quelle touche")
-        a = input('')
-        if a != 'n':
-            setIcon(platform.system(), path)
 
     os.system(commands[sys][0])
     tprint("morpion")
     fill = colored('■', "blue")
     percent = 0
-     
-     
+
 
     for progress in range(0, 1020):
         progress = progress/10
@@ -86,12 +55,7 @@ def loading(currentVersion, path, SavePath):
     bar = f"Loading  |{fill*50}| 100 %        "
 
     print(bar)
-    print('Checking for updates...')
-    if internet_on():
-        os.system(commands[sys][2])
-        v = pkg_resources.get_distribution("Morpion").version
-        if v != currentVersion:
-            os.system(f"{commands[sys][3]} ")
+
 
     time.sleep(1)
     os.system(commands[sys][0])
